"use strict";

exports.__esModule = true;
exports.default = void 0;

/**
 * Custom converter for the class name
 *
 * @callback classNameConverter
 * @param {string} className - The class name.
 */

/**
 * Provides a wrapper around an API similar to [classnames#bind](https://github.com/JedWatson/classnames#alternate-bind-version-for-css-modules)
 * that also supports converting class names before they are looked up in
 * the `classNameMap`.
 *
 * @param {Record<string, string>} localClassNameMap - A map of class names
 * @param {Record<string, string>} globalClassNameMap - A map of class names
 * @param {classNameConverter} classNameConverter - A callback function to convert the class name before being looked up in the class name map
 *
 * @returns {function(...[*]): string} - Returns an API equivalent to [classnames](https://github.com/JedWatson/classnames#usage).
 */
function createClassNames(localClassNameMap, globalClassNameMap, classNameConverter) {
  if (localClassNameMap === void 0) {
    localClassNameMap = {};
  }

  if (globalClassNameMap === void 0) {
    globalClassNameMap = {};
  }

  if (classNameConverter === void 0) {
    classNameConverter = function classNameConverter(className) {
      return className;
    };
  }

  return function internalClassNames() {
    for (var _len = arguments.length, classNamesOrObjects = new Array(_len), _key = 0; _key < _len; _key++) {
      classNamesOrObjects[_key] = arguments[_key];
    }

    var finalClassNames = classNamesOrObjects.filter(function (item) {
      return item;
    }).map(function (item) {
      function convert(className) {
        var convertedClassName = classNameConverter(className);

        if (localClassNameMap[convertedClassName]) {
          return localClassNameMap[convertedClassName];
        }

        if (globalClassNameMap[convertedClassName]) {
          return globalClassNameMap[convertedClassName];
        }

        if (className.trim().indexOf(' ') > -1) {
          return internalClassNames.apply(void 0, className.trim().split(' '));
        }

        return className;
      }

      var itemType = typeof item;

      if (itemType === 'string' || itemType === 'number') {
        return convert("" + item);
      }

      if (Array.isArray(item)) {
        return internalClassNames.apply(void 0, item);
      }

      if (itemType === 'object') {
        return internalClassNames(Object.keys(item).filter(function (key) {
          return item[key];
        }));
      }

      return null;
    }).filter(function (item) {
      return item !== null;
    }).join(' ').trim();
    return finalClassNames.length > 0 ? finalClassNames : null;
  };
}

var _default = createClassNames;
exports.default = _default;
module.exports = exports["default"];